@@ -1,10 +1,10 @@
 from datetime import datetime, timedelta
 
-from cryptography.hazmat.primitives.asymmetric import rsa
 from cryptography import x509
-from cryptography.x509.oid import NameOID
 from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives.serialization import load_pem_public_key, Encoding, PrivateFormat, NoEncryption
+from cryptography.hazmat.primitives.asymmetric import rsa
+from cryptography.hazmat.primitives.serialization import Encoding, NoEncryption, PrivateFormat, load_pem_public_key
+from cryptography.x509.oid import NameOID
 
 
 def make_cert(key, public_key, common_name=None):
@@ -17,7 +17,7 @@ def make_cert(key, public_key, common_name=None):
     cert = cert.serial_number(1)
     cert = cert.not_valid_before(datetime.utcnow() - timedelta(minutes=1))
     cert = cert.not_valid_after(datetime.utcnow() + timedelta(days=365 * 10))
-    cert = cert.sign(key, hashes.SHA1())
+    cert = cert.sign(key, hashes.SHA256())
     return cert
 
 
